-- Copyright Materialize, Inc. and contributors. All rights reserved.
--
-- Licensed under the Apache License, Version 2.0 (the "License");
-- you may not use this file except in compliance with the License.
-- You may obtain a copy of the License in the LICENSE file at the
-- root of this repository, or online at
--
--     http://www.apache.org/licenses/LICENSE-2.0
--
-- Unless required by applicable law or agreed to in writing, software
-- distributed under the License is distributed on an "AS IS" BASIS,
-- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-- See the License for the specific language governing permissions and
-- limitations under the License.

{% macro mz_generate_name(identifier) -%}
    {{ exceptions.warn(
        """
        The mz_generate_name macro is deprecated and will be removed in a future release of dbt-materialize.
        Please use the {{ this }} jinja function to reference the relation instead:

        e.g.
        {{ config(materialized=''source'') }}

        CREATE SOURCE {{ this }} ...

        Will create a source using the filename as the identifier.
        Documentation for {{ this }} can be found: https://docs.getdbt.com/reference/dbt-jinja-functions/this
        """
    )}}
  {{ return("{}.{}.{}".format(database, schema, identifier)) }}
{% endmacro %}
